@@ -1,7 +1,7 @@
-from core import StringLike
+from stringlike.core import StringLike
 
 
-__version__ = '0.3.0'
+__version__ = '0.3.1'
 VERSION = tuple(map(int, __version__.split('.')))
 
 __all__ = ['StringLike']
